WalletData

Struct WalletData 

pub struct WalletData { /* private fields */ }
Wallet information without any browser function calls for wallet-adapter standard operations

Implementations

Source

impl WalletData

pub fn new() -> Self

Instantiate a new WalletData

pub fn set_name(self, name: &str) -> Self

Set the name of the wallet

pub fn set_version(self, version: SemverVersion) -> Self

Set the Semver version of the wallet

pub fn set_icon(self, icon: Option<impl ToString>) -> Self

Set the icon of the wallet. Should be in Base64 URL web format data:image/${'svg+xml' | 'webp' | 'png' | 'gif'};base64,${string}

pub fn add_account(self, account: WalletAccountData) -> Self

Add a Wallet account data

pub fn add_accounts(self, accounts: &[WalletAccountData]) -> Self

Add multiple Wallet account data(s)

pub fn replace_accounts(self, accounts: Vec<WalletAccountData>) -> Self

Replace all Wallet account data

pub fn add_chain(self, chain: Cluster) -> Self

Add a Cluster

pub fn add_chains(self, chains: &[Cluster]) -> Self

Add multiple Clusters

pub fn replace_chains(self, chains: Vec<Cluster>) -> Self

Replace existing Clusters

pub fn set_supported_features(self, supported_features: FeatureSupport) -> Self

Set the supported wallet features

pub fn set_supported_chains(self, supported_chains: ChainSupport) -> Self

Set the chains supported by the wallet

pub fn accounts(&self) -> &[WalletAccountData]

Get the accounts provided by the wallet

pub fn chains(&self) -> &[Cluster]

Get the chains supported by the wallet

pub fn mainnet(&self) -> bool

Check whether the wallet supports mainnet cluster

pub fn devnet(&self) -> bool

Check whether the wallet supports devnet cluster

pub fn testnet(&self) -> bool

Check whether the wallet supports testnet cluster

pub fn localnet(&self) -> bool

Check whether the wallet supports localnet cluster

pub fn standard_connect(&self) -> bool

Check whether the wallet supports standard:connect feature

pub fn standard_disconnect(&self) -> bool

Check whether the wallet supports standard:disconnect feature

pub fn standard_events(&self) -> bool

Check whether the wallet supports standard:events feature

pub fn solana_signin(&self) -> bool

Check whether the wallet supports solana:signIn feature

pub fn solana_sign_message(&self) -> bool

Check whether the wallet supports solana:signMessage feature

pub fn solana_sign_and_send_transaction(&self) -> bool

Check whether the wallet supports solana:signAndSendTransaction feature

pub fn solana_sign_transaction(&self) -> bool

Check whether the wallet supports solana:signTransaction feature

pub fn icon(&self) -> Option<&Cow<'static, str>>

Get the optional Wallet Icon

pub fn name(&self) -> &str

Get the name of the wallet

pub fn version(&self) -> &SemverVersion

Get the version of the wallet standard that the wallet supports